# Publish

## Publish package to GitLab Package Registry

### Requirements

- Python >= 3.10
- Network access granted to:
  - the GitLab instance
  - <https://pypi.org>
- a deploy token with `read_package_registry` and `write_package_registry` scope

> See: [GitLab documentation about publishing to the package registry](https://docs.gitlab.com/ee/user/packages/pypi_repository/)

### Configuration

Fill the `.pypirc` file with the credentials.

From here, we use the deploy token:

```ini
; deploy for project using group deploy token
; see: https://gitlab.gpf-tech.ign.fr/groups/geoplateforme/scripts-verification/-/settings/repository
[gitlab-gpf-prj-dt]
repository = https://gitlab.gpf-tech.ign.fr/api/v4/projects/176/packages/pypi
username =
password =
```

### Build and upload with twine

1. Install/upgrade twine:

    ```sh
    python3 -m pip install -U build "twine<5"
    ```

1. Clean previous builds:

    ```sh
    rm -R dist/
    ```

1. Build the new version:

    ```sh
    python setup.py sdist bdist_wheel
    ```

    Alternatively:

    ```sh
    python -m pip install -U build
    python -m build -n --sdist --wheel --outdir dist/ .
    ```

1. Upload it to the package registry:

    ```sh
    HTTPS_PROXY=socks5://127.0.0.1:8645 twine upload --repository-url https://gitlab.gpf-tech.ign.fr/api/v4/projects/214/packages/pypi/ --verbose dist/*
    ```

### Proxy support

#### Socks5 proxy

Install PySocks:

```sh
pip install -U "PySocks<2"
```

Example with a proxy on `127.0.0.1:8645`:

```sh
HTTPS_PROXY=socks5://127.0.0.1:8645 twine upload --config-file .pypirc --repository gitlab-gpf-checks-dt --verbose dist/*
```

> See: [Twine documentation](https://twine.readthedocs.io/en/stable/index.html#proxy-support)
