# Configurer l'environnement de développement

## Prérequis système

- Python >= 3.10
- GDAL >= 3.4
- Accès réseau sur :
  - l'instance GitLab : <https://gitlab.gpf-tech.ign.fr>
  - le dépôt officiel de paquets Python : <https://pypi.org/>
- un jeton d'accès personnel (_Personal Access Token (PAT)_) avec le scope `read_api` ou a minima `read_registry`. Voir la page [Authentification](/usage/authentication).

## Cloner le dépôt

Exemple pour Oslandia avec l'utilisateur `geojulien` :

```sh
git clone --config 'credential.helper=store' https://geojulien@gitlab.gpf-tech.ign.fr/geoplateforme/traitements-vecteurs/livraison-to-bdd.git
```

### Derrière le proxy

L'Usine Logicielle étant en accès restreint derrière un filtre IP, les personnes ne disposant pas d'IP fixe passent par un proxy qui pointe sur un serveur de rebond dont l'IP fixe est autorisée.

Exemple avec un proxy de type socks :

```sh
git clone --config http.proxy='socks5://127.0.0.1:8645' --config 'credential.helper=store' https://geojulien@gitlab.gpf-tech.ign.fr/geoplateforme/traitements-vecteurs/livraison-to-bdd.git
```

----

## Démarrage rapide

> Exemple sur une distribution Linux de type Ubuntu LTS.

Définir la version à utiliser :

```sh
export GDAL_VERSION=3.*
# ou plus strictement : export GDAL_VERSION=3.4.1
```

Installer GDAL :

```sh
sudo apt install gdal-bin=$GDAL_VERSION libgdal-dev=$GDAL_VERSION
```

Ajouter les chemins utiles pour builder en variables d'environnement :

```sh
export CPLUS_INCLUDE_PATH=/usr/include/gdal
export C_INCLUDE_PATH=/usr/include/gdal
```

### Environnement virtuel

Installer dans un environnement virtuel :

```sh
# environnement virtuel
python3 -m venv .venv
source .venv/bin/activate
# mise à jour de pip dans l'environnement virtuel
python -m pip install -U pip setuptools wheel
# installation des dépendances de base
python -m pip install -r requirements.txt
# installation du projet en mode développement avec la version de GDAL du système
python -m pip install -e .[gdal]
```

### Système

Pour une installation au niveau du système :

```sh
python3 -m pip install -U setuptools wheel
python3 -m pip install gdal=="`gdal-config --version`.*"
python3 -m pip install -U -r requirements.txt
python3 -m pip install -e .
```

### Derrière un proxy

Pour les proxy de type socks, installer préalablement PySocks dans le même environnement que le reste :

```sh
python -m pip install -U "PySocks<2"
```

Puis installer tour à tour les dépendances issues de <pypi.org> puis celles du registre de l'Usine Logicielle :

```sh
python -m pip install gdal=="`gdal-config --version`.*"
python -m pip install -U -r requirements/base-pypi.txt
python -m pip install -U -r requirements/base-gpf.txt --proxy socks5://localhost:8645 --extra-index-url https://gitlab.gpf-tech.ign.fr/api/v4/groups/55/-/packages/pypi/simple --retries 1
python -m pip install -e .
```
