-- ==========================================================================
-- =============== DU & COMMUNES 3.0                                =========
-- ==========================================================================


-- Ajout de la couche des commnunes pour la vue des RNU
CREATE TABLE municipality
(
  gid serial NOT NULL,
  insee character varying(5),
  name character varying(80),
  is_rnu BOOLEAN,
  is_deleted BOOLEAN,
  CONSTRAINT municipality_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn(''::text, 'municipality'::text, 'the_geom'::text, 4326, 'GEOMETRY'::text, 2, true) ;

CREATE INDEX municipality_geom_gist
  ON municipality
  USING GIST (the_geom) ;

-- Couche document pour la vue des DU à petite echelle

CREATE TABLE document
(
  gid serial NOT NULL,
  id character varying(32),
  grid_name character varying(50),
  grid_title text,
  name character varying(50),
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  du_type character varying(4),
  CONSTRAINT document_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'document', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX document_geom_gist
  ON document
  USING GIST (the_geom) ;

-- doc_urba

CREATE TABLE doc_urba
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  idurba character varying(30),
  typedoc character varying(4),
  datappro character varying(10),
  datefin character varying(10),
  interco character varying(1),
  siren character varying(9),
  etat character varying(2),
  nomreg character varying(80),
  urlreg character varying(254),
  nomplan character varying(80),
  urlplan character varying(254),
  siteweb character varying(254),
  typeref character varying(15),
  dateref character varying(10),
  nomproc character varying(10),
  urlpe character varying(254),
  CONSTRAINT doc_urba_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'doc_urba', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE TABLE doc_urba_com
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  idurba character varying(30),
  insee character varying(5),
  datecog character varying(10),
  CONSTRAINT doc_urba_com_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'doc_urba_com', 'the_geom', 4326, 'GEOMETRY', 2, true) ;


----------------------------------------------------------
-- INFO --------------------------------------------------
----------------------------------------------------------

CREATE TABLE info_pct
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  txt character varying(10),
  typeinf character varying(2),
  typep character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  idurba character varying(30),
  datvalid character varying(10),
  stypeinf character varying(2),
  stypep character varying(2),
  idinfo character varying(40),
  lib_idinfo character varying(40),
  CONSTRAINT info_pct_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'info_pct', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX info_pct_geom_gist
  ON info_pct
  USING GIST (the_geom) ;

CREATE TABLE info_lin
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  txt character varying(10),
  typeinf character varying(2),
  typep character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  idurba character varying(30),
  datvalid character varying(10),
  stypeinf character varying(2),
  stypep character varying(2),
  idinfo character varying(40),
  lib_idinfo character varying(40),
  CONSTRAINT info_lin_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'info_lin', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX info_lin_geom_gist
  ON info_lin
  USING GIST (the_geom) ;

CREATE TABLE info_surf
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  txt character varying(10),
  typeinf character varying(2),
  typep character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  idurba character varying(30),
  datvalid character varying(10),
  stypeinf character varying(2),
  stypep character varying(2),
  idinfo character varying(40),
  lib_idinfo character varying(40),
  CONSTRAINT info_surf_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'info_surf', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX info_surf_geom_gist
  ON info_surf
  USING GIST (the_geom) ;


----------------------------------------------------------
-- PRESCRIPTION ------------------------------------------
----------------------------------------------------------


CREATE TABLE prescription_pct
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  txt character varying(10),
  typepsc character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  angle integer,
  datappro character varying(10),
  datvalid character varying(10),
  idurba character varying(30),
  stypepsc character varying(2),
  idpsc character varying(40),
  lib_idpsc character varying(40),
  CONSTRAINT prescription_pct_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'prescription_pct', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX prescription_pct_geom_gist
  ON prescription_pct
  USING GIST (the_geom) ;


CREATE TABLE prescription_lin
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  txt character varying(10),
  typepsc character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  datappro character varying(10),
  datvalid character varying(10),
  idurba character varying(30),
  stypepsc character varying(2),
  idpsc character varying(40),
  lib_idpsc character varying(40),
  CONSTRAINT prescription_lin_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'prescription_lin', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX prescription_lin_geom_gist
  ON prescription_lin
  USING GIST (the_geom) ;


CREATE TABLE prescription_surf
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(300),
  txt character varying(10),
  typepsc character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  datappro character varying(10),
  datvalid character varying(10),
  idurba character varying(30),
  stypepsc character varying(2),
  idpsc character varying(40),
  lib_idpsc character varying(40),
  CONSTRAINT prescription_surf_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'prescription_surf', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX prescription_surf_geom_gist
  ON prescription_surf
  USING GIST (the_geom) ;

----------------------------------------------------------
-- SECTEUR CC ---------------------------------------------
----------------------------------------------------------

CREATE TABLE secteur_cc
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(254),
  libelong character varying(254),
  typesect character varying(3),
  fermreco character varying(3),
  destdomi character varying(2),
  nomfic character varying(254),
  urlfic character varying(254),
  insee character varying(5),
  datappro character varying(10),
  datvalid character varying(10),
  idurba character varying(30),
  lib_idzone character varying(40),
  CONSTRAINT secteur_cc_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn(''::text, 'secteur_cc'::text, 'the_geom'::text, 4326, 'GEOMETRY'::text, 2, true) ;

CREATE INDEX secteur_cc_geom_gist
  ON secteur_cc
  USING GIST (the_geom) ;

----------------------------------------------------------
-- HABILLAGE    ------------------------------------------
----------------------------------------------------------


CREATE TABLE habillage_lin
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  nattrac character varying(40),
  insee character varying(5),
  idurba character varying(30),
  couleur character varying(11),
  idhab character varying(40),
  lib_idhab character varying(40),
  CONSTRAINT habillage_lin_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'habillage_lin', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX habillage_lin_geom_gist
  ON habillage_lin
  USING GIST (the_geom) ;


CREATE TABLE habillage_pct
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  nattrac character varying(40),
  insee character varying(5),
  idurba character varying(30),
  couleur character varying(11),
  idhab character varying(40),
  lib_idhab character varying(40),
  CONSTRAINT habillage_pct_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'habillage_pct', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX habillage_pct_geom_gist
  ON habillage_pct
  USING GIST (the_geom) ;



CREATE TABLE habillage_surf
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  nattrac character varying(40),
  insee character varying(5),
  idurba character varying(30),
  couleur character varying(11),
  idhab character varying(40),
  lib_idhab character varying(40),
  CONSTRAINT habillage_surf_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'habillage_surf', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX habillage_surf_geom_gist
  ON habillage_surf
  USING GIST (the_geom) ;



CREATE TABLE habillage_txt
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  natecr character varying(80),
  insee character varying(5),
  txt character varying(80),
  police character varying(40), -- new 2.0
  taille integer,               -- new 2.0
  style character varying(40),  -- new 2.0
  angle integer,                -- new 2.0
  idurba character varying(30),
  couleur character varying(11),
  idhab character varying(40),
  lib_idhab character varying(40),
  CONSTRAINT habillage_txt_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'habillage_txt', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX habillage_txt_geom_gist
  ON habillage_txt
  USING GIST (the_geom) ;




----------------------------------------------------------
-- ZONE URBA ---------------------------------------------
----------------------------------------------------------

CREATE TABLE zone_urba
(
  gid serial NOT NULL,
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  libelle character varying(12),
  libelong character varying(300),
  typezone character varying(3),
  destdomi character varying(2),
  nomfic character varying(80),
  urlfic character varying(254),
  insee character varying(5),
  datappro character varying(10),
  datvalid character varying(10),
  idurba character varying(30),
  idzone character varying(40),
  lib_idzone character varying(40),
  CONSTRAINT zone_urba_pkey PRIMARY KEY (gid)
) ;

SELECT addGeometryColumn('', 'zone_urba', 'the_geom', 4326, 'GEOMETRY', 2, true) ;

CREATE INDEX zone_urba_geom_gist
  ON zone_urba
  USING GIST (the_geom) ;

-- ==========================================================================
-- =============== MÉTADONNÉES ==============================================
-- ==========================================================================

CREATE TABLE partition_metadata
(
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  uuid character varying(255)
) ;

-- ==========================================================================
-- =============== RASTERISATION ============================================
-- ==========================================================================

CREATE TABLE partition_rasterisation
(
  gpu_doc_id character varying(32),
  gpu_status character varying(16),
  gpu_timestamp timestamp without time zone,
  partition character varying(32),
  layer character varying(64),
  CONSTRAINT partition_rasterisation_pkey PRIMARY KEY (partition, layer)
) ;

SELECT addGeometryColumn('', 'partition_rasterisation', 'the_geom', 4326, 'GEOMETRY', 2, true) ;


CREATE VIEW view_partition_metadata AS
  SELECT *
  FROM partition_metadata;