#!/usr/bin/env python3  # noqa E265

"""
    Usage from the repo root folder:

    .. code-block:: bash
        # for whole tests
        python -m unittest tests.test_utils_list_files
        # for specific test
        python -m unittest tests.test_utils_list_files.TestUtilsListFiles.test_main
"""


# standard library
import unittest
from pathlib import Path, PosixPath

# project
from gpf_vector_to_db.utils.list_files import list_authorized_files

# ############################################################################
# ########## Classes #############
# ################################


class TestUtilsListFiles(unittest.TestCase):
    """Test package metadata."""

    def test_main(self):
        """main test"""
        test = sorted(
            list_authorized_files(
                Path("tests/fixtures/data/normal"), multigeom_layers=["test_ajout"]
            ),
            key=lambda d: d["name"],
        )
        result = [
            {
                "path": PosixPath("tests/fixtures/data/normal/shp/test_ajout.shp"),
                "type": "ESRI Shapefile",
                "name": "test_ajout",
                "srid": "WGS 84",
                "status": "GENERATING",
                "force_multi": True,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/shp/test_base.shp"),
                "type": "ESRI Shapefile",
                "name": "test_base",
                "srid": "WGS 84",
                "status": "GENERATING",
                "force_multi": False,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/csv/test_Base_XY.csv"),
                "type": "CSV",
                "name": "test_base_xy",
                "srid": "EPSG:4326",
                "status": "GENERATING",
                "force_multi": False,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/gpkg/test_base.gpkg"),
                "type": "GPKG",
                "name": "test_line",
                "srid": "WGS 84",
                "status": "GENERATING",
                "force_multi": False,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/gpkg/test_base.gpkg"),
                "type": "GPKG",
                "name": "test_point",
                "srid": "WGS 84",
                "status": "GENERATING",
                "force_multi": False,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/gpkg/test_base.gpkg"),
                "type": "GPKG",
                "name": "test_polygon",
                "srid": "WGS 84",
                "status": "GENERATING",
                "force_multi": False,
            },
            {
                "path": PosixPath("tests/fixtures/data/normal/gpkg/test_base.gpkg"),
                "type": "GPKG",
                "name": "test_xy",
                "srid": "EPSG:4326",
                "status": "GENERATING",
                "force_multi": False,
            },
        ]
        print(test)
        print(result)
        self.assertTrue(len(test) == len(result))
        for i in test:
            print(i)
            self.assertTrue(i in result)
        # self.assertTrue(test == result)


# ############################################################################
# ####### Stand-alone run ########
# ################################
if __name__ == "__main__":
    unittest.main()
